==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-63.js <==
dispMUA.arDispMUAAllocation["c"] =
{
  "cart managment system at http://www.linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "correo electrónico de internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "cart managment system at http://linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "coppermine photo gallery" : [ "coppermine.png" ] ,
  "coremail webmail server" : [ "163_com.png" , "http://www.mailtech.cn/" ] ,
  "cakephp email component" : [ "cakephp.png" ] ,
  "codestone mail control" : [ "codestone.png" , "http://www.codestone.ltd.uk/" ] ,
  "clever internet suite" : [ "cis5.png" ] ,
  "calcium web calendar" : [ "calcium.png" , "http://www.brownbearsw.com/calcium/" ] ,
  "crosspoint [openxp/" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "cpjnssmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "cookie craft server" : [ "cookie_craft.png" ] ,
  "com.oreilly.servlet" : [ "servlets_com.png" , "http://www.servlets.com/cos/" ] ,
  "chorus by zerocode" : [ "zerocode.png" ] ,
  "crosspoint/openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "crosspoint/freexp" : [ "crosspoint_freexp.png" , "http://www.freexp.de/" ] ,
  "clear net webmail" : [ "clearnet.png" ] ,
  "copia emailfacts" : [ "copia_emailfacts.png" ] ,
  "cf_advancedemail" : [ "coldfusion.png" , "http://www.vandieten.net/jochem/coldfusion/customtags/advancedemail/" ] ,
  "cas genesisworld" : [ "genesis_world.png" ] ,
  "csmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "crosspoint [xp2" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
  "coolblue-mailer" : [ "coolblue.png" ] ,
  "cyberghost vpn" : [ "cyberghostvpn.png" , "http://www.cyberghostvpn.com/" ] ,
  "consol*cm-mail" : [ "consol_cm.png" , "http://www.consol.de/unternehmen/infomaterial/" ] ,
  "cogeco webmail" : [ "cogeco_ca.png" , "http://www.cogeco.ca/" ] ,
  "claris emailer" : [ "claris_emailer.png" ] ,
  "cappuccino crm" : [ "cappuchino.png" ] ,
  "cad-kas mailer" : [ "cadkas_com.png" , "http://www.cadkas.com/" ] ,
  "c't-emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "cu newsletter" : [ "cleverinternetsuite.png" , "http://www.clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "ctm powermail" : [ "ctm_powermail.png" , "http://www.ctmdev.com/" ] ,
  "compost carma" : [ "compost_carma.png" , "http://www.compost.se/en/carma/" ] ,
  "codes-sources" : [ "code-source.png" ] ,
  "custommailer" : [ "custommailer.png" , "http://www.wildcrest.com/" ] ,
  "copland mail" : [ "copland_udel_edu.png" , "http://copland.udel.edu/" ] ,
  "coldfusion 8" : [ "coldfusion8.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "coelnconcept" : [ "coelnconcept_de.png" , "http://www.coelnconcept.de/" ] ,
  "chatteremail" : [ "chatteremail.png" ] ,
  "centrum mail" : [ "centrum_cz.png" , "http://www.centrum.cz/" ] ,
  "center parcs" : [ "centerparcs_de.png" , "http://www.centerparcs.de/" ] ,
  "catchme@mail" : [ "catchmeatmail.png" ] ,
  "carookee.com" : [ "carookee_com.png" , "http://www.carookee.com/" ] ,
  "communigate" : [ "communigate.png" ] ,
  "com.zooplus" : [ "zooplus_de.png" , "http://www.zooplus.de/" ] ,
  "codeigniter" : [ "codeigniter.png" , "http://codeigniter.com/" ] ,
  "clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "cb javamail" : [ "java.png" ] ,
  "crosspoint" : [ "crosspoint.png" , "http://www.crosspoint.de/" ] ,
  "createsend" : [ "createsend.png" , "http://www.createsend.com/" ] ,
  "contactlab" : [ "contactlab.png" , "http://www.contactlab.it/" ] ,
  "compuserve" : [ "compuserve.png" ] ,
  "coldfusion" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "cmmx01.dll" : [ "combit.png" , "http://www.combit.net/" ] ,
  "claws mail" : [ "claws-mail.png" ] ,
  "chili!soft" : [ "chilisoft.png" , "http://www.chilisoft.com/" ] ,
  "cacert.org" : [ "cacert.png" ] ,
  "ca_mailer/" : [ "ca_mailer.png" , "http://pro.channeladvisor.de/" ] ,
  "cvsmailer" : [ "cvsmailer.png" ] ,
  "citromail" : [ "citromail.png" ] ,
  "chordiant" : [ "chordiant.png" , "http://www.chordiant.com/" ] ,
  "cacaomail" : [ "cacaomail.png" , "http://ooyes.net/" ] ,
  "cliffmoe" : [ "cliffmoe_com.png" , "http://www.cliffmoe.com/" ] ,
  "chauntry" : [ "chauntry.png" , "http://www.chauntry.com/" ] ,
  "chandler" : [ "chandler.png" , "http://chandlerproject.org/" ] ,
  "cerberus" : [ "cerberus_helpdesk.png" , "http://www.cerberusweb.com/" ] ,
  "caramail" : [ "lycos.png" ] ,
  "cabestan" : [ "cabestan.png" , "http://www.cabestan.com/" ] ,
  "cvsspam" : [ "cvs.png" ] ,
  "confixx" : [ "confixx.png" ] ,
  "columba" : [ "columba.png" ] ,
  "cmail10" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail11" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail12" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail13" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail14" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail15" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail16" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail17" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail18" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail19" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail20" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail21" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail22" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail23" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail24" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail25" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail26" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail27" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail28" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail29" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail30" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "chilkat" : [ "chilkat.png" , "http://www.chilkatsoft.com/" ] ,
  "cbizone" : [ "cbizone.png" , "http://www.cbizsoft.com/" ] ,
  "cbfmail" : [ "cardboardfish_com.png" , "http://www.cardboardfish.com/" ] ,
  "calypso" : [ "calypso.png" ] ,
  "cybozu" : [ "cybozu.png" ] ,
  "cwmail" : [ "netwinsite.png" , "http://netwinsite.com/cwmail/" ] ,
  "cmail1" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail2" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail3" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail4" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail5" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail6" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail7" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail8" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail9" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "clx.ru" : [ "clx_ru.png" , "http://www.clx.ru/" ] ,
  "chikka" : [ "chikka.png" , "http://www.chikka.com/txt2mail/" ] ,
  "cpdev" : [ "cpdev.png" , "http://www.cpdev.co.uk/" ] ,
  "cisco" : [ "cisco.png" , "http://www.cisco.com/" ] ,
  "camas" : [ "caudium.png" , "http://www.caudium.net/" ] ,
  "cms " : [ "hypernews.png" , "http://hypernews.slac.stanford.edu/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-63.js <==
dispMUA.arDispMUAAllocation["c"] =
{
  "cart managment system at http://www.linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "correo electrónico de internet de microsoft/mapi" : [ "ms_patch.png" , "http://www.microsoft.com/" ] ,
  "cart managment system at http://linuxcenter.ru" : [ "linuxcenter_ru.png" , "http://www.linuxcenter.ru/" ] ,
  "coppermine photo gallery" : [ "coppermine.png" ] ,
  "coremail webmail server" : [ "163_com.png" , "http://www.mailtech.cn/" ] ,
  "cakephp email component" : [ "cakephp.png" ] ,
  "codestone mail control" : [ "codestone.png" , "http://www.codestone.ltd.uk/" ] ,
  "clever internet suite" : [ "cis5.png" ] ,
  "calcium web calendar" : [ "calcium.png" , "http://www.brownbearsw.com/calcium/" ] ,
  "crosspoint [openxp/" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "cpjnssmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "cookie craft server" : [ "cookie_craft.png" ] ,
  "com.oreilly.servlet" : [ "servlets_com.png" , "http://www.servlets.com/cos/" ] ,
  "chorus by zerocode" : [ "zerocode.png" ] ,
  "crosspoint/openxp" : [ "crosspoint_openxp.png" , "http://www.openxp.de/" ] ,
  "crosspoint/freexp" : [ "crosspoint_freexp.png" , "http://www.freexp.de/" ] ,
  "clear net webmail" : [ "clearnet.png" ] ,
  "copia emailfacts" : [ "copia_emailfacts.png" ] ,
  "cf_advancedemail" : [ "coldfusion.png" , "http://www.vandieten.net/jochem/coldfusion/customtags/advancedemail/" ] ,
  "cas genesisworld" : [ "genesis_world.png" ] ,
  "csmtpconnection" : [ "cpjnsmtpconnection.png" ] ,
  "crosspoint [xp2" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
  "coolblue-mailer" : [ "coolblue.png" ] ,
  "cobian backup 9" : [ "cobianbackup9.png" , "http://www.cobian.se/" ] ,
  "cobian backup 8" : [ "cobianbackup8.png" , "http://www.cobian.se/" ] ,
  "cobian backup 7" : [ "cobianbackup7.png" , "http://www.cobian.se/" ] ,
  "cleancode.email" : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "cyberghost vpn" : [ "cyberghostvpn.png" , "http://www.cyberghostvpn.com/" ] ,
  "consol*cm-mail" : [ "consol_cm.png" , "http://www.consol.de/unternehmen/infomaterial/" ] ,
  "cogeco webmail" : [ "cogeco_ca.png" , "http://www.cogeco.ca/" ] ,
  "claris emailer" : [ "claris_emailer.png" ] ,
  "cappuccino crm" : [ "cappuchino.png" ] ,
  "cad-kas mailer" : [ "cadkas_com.png" , "http://www.cadkas.com/" ] ,
  "c't-emailcheck" : [ "heise_security.png" , "http://www.heise.de/security/dienste/emailcheck/" ] ,
  "cu newsletter" : [ "cleverinternetsuite.png" , "http://www.clevercomponents.com/products/inetsuite/suite.asp" ] ,
  "cu mailsystem" : [ "computeruniverse.png" , "http://www.computeruniverse.net/" ] ,
  "ctm powermail" : [ "ctm_powermail.png" , "http://www.ctmdev.com/" ] ,
  "compost carma" : [ "compost_carma.png" , "http://www.compost.se/en/carma/" ] ,
  "codes-sources" : [ "code-source.png" ] ,
  "cobian backup" : [ "cobian.png" , "http://www.cobian.se/" ] ,
  "cdrwinkel.com" : [ "cdrwinkel.png" , "http://www.cdrwinkel.com/" ] ,
  "custommailer" : [ "custommailer.png" , "http://www.wildcrest.com/" ] ,
  "copland mail" : [ "copland_udel_edu.png" , "http://copland.udel.edu/" ] ,
  "coldfusion 8" : [ "coldfusion8.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "coelnconcept" : [ "coelnconcept_de.png" , "http://www.coelnconcept.de/" ] ,
  "chatteremail" : [ "chatteremail.png" ] ,
  "centrum mail" : [ "centrum_cz.png" , "http://www.centrum.cz/" ] ,
  "center parcs" : [ "centerparcs_de.png" , "http://www.centerparcs.de/" ] ,
  "catchme@mail" : [ "catchmeatmail.png" ] ,
  "carookee.com" : [ "carookee_com.png" , "http://www.carookee.com/" ] ,
  "communigate" : [ "communigate.png" ] ,
  "com.zooplus" : [ "zooplus_de.png" , "http://www.zooplus.de/" ] ,
  "codeigniter" : [ "codeigniter.png" , "http://codeigniter.com/" ] ,
  "clickmailer" : [ "clickmailer.png" , "http://www.clickmailer.jp/" ] ,
  "cb javamail" : [ "java.png" , "http://java.sun.com/products/javamail/" ] ,
  "crosspoint" : [ "crosspoint.png" , "http://www.crosspoint.de/" ] ,
  "createsend" : [ "createsend.png" , "http://www.createsend.com/" ] ,
  "contactlab" : [ "contactlab.png" , "http://www.contactlab.it/" ] ,
  "compuserve" : [ "compuserve.png" ] ,
  "coldfusion" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "cmmx01.dll" : [ "combit.png" , "http://www.combit.net/" ] ,
  "claws mail" : [ "claws-mail.png" ] ,
  "chili!soft" : [ "chilisoft.png" , "http://www.chilisoft.com/" ] ,
  "cacert.org" : [ "cacert.png" , "http://www.cacert.org/" ] ,
  "ca_mailer/" : [ "ca_mailer.png" , "http://pro.channeladvisor.de/" ] ,
  "cvsmailer" : [ "cvsmailer.png" ] ,
  "citromail" : [ "citromail.png" ] ,
  "chordiant" : [ "chordiant.png" , "http://www.chordiant.com/" ] ,
  "cacaomail" : [ "cacaomail.png" , "http://ooyes.net/" ] ,
  "cliffmoe" : [ "cliffmoe_com.png" , "http://www.cliffmoe.com/" ] ,
  "chauntry" : [ "chauntry.png" , "http://www.chauntry.com/" ] ,
  "chandler" : [ "chandler.png" , "http://chandlerproject.org/" ] ,
  "cerberus" : [ "cerberus_helpdesk.png" , "http://www.cerberusweb.com/" ] ,
  "caramail" : [ "lycos.png" , "http://www.caramail.lycos.fr/" ] ,
  "carteiro" : [ "carteiro.png" , "http://www.linkws.com/br/marketing/carteiro_apres.htm" ] ,
  "cabestan" : [ "cabestan.png" , "http://www.cabestan.com/" ] ,
  "cvsspam" : [ "cvs.png" ] ,
  "confixx" : [ "confixx.png" ] ,
  "columba" : [ "columba.png" ] ,
  "cmail10" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail11" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail12" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail13" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail14" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail15" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail16" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail17" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail18" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail19" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail20" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail21" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail22" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail23" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail24" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail25" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail26" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail27" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail28" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail29" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail30" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "chilkat" : [ "chilkat.png" , "http://www.chilkatsoft.com/" ] ,
  "cbizone" : [ "cbizone.png" , "http://www.cbizsoft.com/" ] ,
  "cbfmail" : [ "cardboardfish_com.png" , "http://www.cardboardfish.com/" ] ,
  "calypso" : [ "calypso.png" ] ,
  "cybozu" : [ "cybozu.png" ] ,
  "cwmail" : [ "netwinsite.png" , "http://netwinsite.com/cwmail/" ] ,
  "cmail1" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail2" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail3" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail4" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail5" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail6" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail7" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail8" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "cmail9" : [ "godaddy.png" , "http://www.godaddy.com/" ] ,
  "clx.ru" : [ "clx_ru.png" , "http://www.clx.ru/" ] ,
  "chikka" : [ "chikka.png" , "http://www.chikka.com/txt2mail/" ] ,
  "cpdev" : [ "cpdev.png" , "http://www.cpdev.co.uk/" ] ,
  "cisco" : [ "cisco.png" , "http://www.cisco.com/" ] ,
  "camas" : [ "caudium.png" , "http://www.caudium.net/" ] ,
  "cms " : [ "hypernews.png" , "http://hypernews.slac.stanford.edu/" ] ,
}
